﻿using System.IO;
using System.Linq;
using System.Xml.Linq;

namespace ProjLinkRemover
{
    class LinksRemover
    {
        private readonly string _sourceProjectFilePath;
        private readonly string _outputDir;

        public LinksRemover(string sourceProjectFilePath, string outputDirectoryPath)
        {
            _sourceProjectFilePath = sourceProjectFilePath;

            _outputDir = outputDirectoryPath;
        }

        public string SourceProjectDirectory
        {
            get { return Path.GetDirectoryName(_sourceProjectFilePath); }
        }

        public void RemoveLinks()
        {
            if (Directory.Exists(_outputDir))
                Directory.Delete(_outputDir, true);
            Directory.CreateDirectory(_outputDir);

            var proj = XElement.Load(_sourceProjectFilePath);
            var ns = proj.GetDefaultNamespace();
            var elements = proj.Elements(ns + "ItemGroup")
                .SelectMany(x => x.Elements())
                .Where(x => x.Attributes(ns + "Include") != null);

            foreach (var element in elements)
            {
                ProcessElement(element);
            }

            var destSlnPath = Path.Combine(_outputDir, Path.GetFileName(_sourceProjectFilePath));
            proj.Save(destSlnPath);
        }

        private void ProcessElement(XElement element)
        {
            switch (element.Name.LocalName)
            {
                case "EmbeddedResource":
                case "Compile":
                case "Content":
                case "None":

                    ProcessFileItem(element);
                    break;
            }
        }

        private void ProcessFileItem(XElement element)
        {
            var includeAttribute = element.Attributes().First(x => x.Name.LocalName == "Include");
            var sourceRelativePath = (string)includeAttribute.Value;
            var sourceAbsolutePath = Path.Combine(SourceProjectDirectory, sourceRelativePath);

            var destRelativePath = sourceRelativePath;
            var linkElement = element.Elements().FirstOrDefault(x => x.Name.LocalName == "Link");
            if (linkElement != null)
            {
                destRelativePath = linkElement.Value;
                includeAttribute.Value = destRelativePath;
                linkElement.Remove();
            }
            var destAbsolutePath = Path.Combine(_outputDir, destRelativePath);

            if (File.Exists(sourceAbsolutePath))
            {
                var dir = Path.GetDirectoryName(destAbsolutePath);
                if (!Directory.Exists(dir))
                    Directory.CreateDirectory(dir);

                File.Copy(sourceAbsolutePath, destAbsolutePath);
            }
        }
    }
}
