﻿using System;
using System.IO;

namespace ProjLinkRemover
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                if (args.Length != 2)
                {
                    ShowUsage();
                    return;
                }

                var projectPath = args[0];
                if (!File.Exists(projectPath))
                {
                    Console.WriteLine("Project file not found: {0}", projectPath);
                    return;
                }

                var destDir = args[1];
                if (Directory.Exists(destDir))
                    Directory.Delete(destDir, true);
                Directory.CreateDirectory(destDir);


                var remover = new LinksRemover(projectPath, destDir);
                remover.RemoveLinks();

                Console.WriteLine("Done.");
            }
            catch (Exception ex)
            {
                Console.WriteLine("An error occured: {0}", ex.Message);
            }
        }

        private static void ShowUsage()
        {
            Console.WriteLine();
            Console.WriteLine("This program replaces file links in Visual Studio Projects with in-place files. USAGE:");
            Console.WriteLine();
            Console.WriteLine("RemoveProjectLinks <project file path> <output directory path>");
            Console.WriteLine();
            Console.WriteLine("<project file path>:");
            Console.WriteLine("\tthe path of your project file(*.csproj, *.vbproj, ...), \r\n\tin which you want to remove file links");
            Console.WriteLine();
            Console.WriteLine("<output directory path>:");
            Console.WriteLine("\tthe path of output directory. All the files of replaced \r\n\tproject will be copied to this directory.");
            Console.WriteLine();
            Console.WriteLine();
            Console.WriteLine("NOTE: All the contents already exsits in the output directory will be deleted!");
        }
    }
}
